.. _getting-started:

Getting started
===============

User Installation
-----------------

As a user, you can install it using `uv <https://docs.astral.sh/uv/>`_ or `pixi <https://pixi.sh>`_
package managers with the following commands (provided you have either uv or pixi installed):

.. code-block:: shell

   $ uv pip install ctao-sat

or:

.. code-block:: shell

   $ pixi add ctao-sat


Also you can install following the traditional way using pip:

.. code-block:: shell

    $ pip install ctao-sat


Developer Setup
---------------

As a developer, clone the repository, create a virtual environment
and then install the package in development mode:

.. code-block:: shell

   $ git clone git@gitlab.cta-observatory.org:cta-computing/suss/science-analysis-tools/science-analysis-tools.git
   $ cd science-analysis-tools
   $ python -m venv venv
   $ source venv/bin/activate
   $ uv pip install -e .[all]

The same also works with conda, create a conda env instead of a venv above. For this, we recommend
using `Miniforge conda/mamba installer <https://github.com/conda-forge/miniforge>`_.
